@@ -6,15 +6,16 @@
 #' http://www.mee.gov.cn/gkml/hbb/bgth/201407/W020140708387895271474.pdf
 #'
 #' @param v Character; category vehicle: "PV" for Passenger Vehicles or 'Trucks"
-#' @param t Character; sub-category of of vehicle: PV:  "Mini", "Small","Medium",
-#' "Large", "Taxi", "Motorcycles", "Moped", "Mediumbus", "Largebus", "3-Wheel" Trucks:
-#' "Mini", "Light" , "Medium", "Heavy"
+#' @param t Character; sub-category of of vehicle: PV Gasoline:  "Mini", "Small","Medium",
+#' "Large", "Taxi", "Motorcycles", "Moped", PV Diesel: "Mediumbus", "Largebus",
+#'  "3-Wheel". Trucks: "Mini", "Light" , "Medium", "Heavy"
 #' @param standard Character or data.frame; "PRE", "I", "II", "III", "IV", "V". When
 #' it is a data.frame, it each row is a different region and ta, humidity,
 #' altitud, speed, sulphur and load_factor lengths have the same as the number of
 #' rows.
 #' @param f Character;fuel: "G", "D"
-#' @param p Character; pollutant: "CO", "NOx","HC", "PM"
+#' @param p Character; pollutant: "CO", "NOx","HC", "PM", "Evaporative_driving"
+#' or "Evaporative_parking"
 #' @param k Numeric; multiplication factor
 #' @param ta Numeric; temperature of ambient in celcius degrees. When standard is a
 #' data.frame, the length must be equal to the number of rows of standard.
@@ -34,22 +35,87 @@
 #' @param correction_only Logical; When TRUE, return only correction factors.
 #' @return An emission factor
 #' @keywords ef_china emission factors China
+#' @note Combination of vehicles:
+#' \tabular{ccc}{
+#'   v    \tab t      \tab    f  \cr
+#'   PV   \tab Mini   \tab   G   \cr
+#'   PV   \tab Small   \tab   G   \cr
+#'   PV   \tab Medium   \tab   G   \cr
+#'   PV   \tab Large   \tab   G   \cr
+#'   PV   \tab Taxi   \tab   G   \cr
+#'   PV   \tab Bus   \tab   G   \cr
+#'   PV   \tab Motorcycles   \tab   G   \cr
+#'   PV   \tab Moped   \tab   G   \cr
+#'   PV   \tab Mini   \tab   D   \cr
+#'   PV   \tab Small   \tab   D   \cr
+#'   PV   \tab Mediumbus   \tab   D   \cr
+#'   PV   \tab Largebus   \tab   D   \cr
+#'   PV   \tab Bus   \tab   D   \cr
+#'   PV   \tab 3-Wheel   \tab   D   \cr
+#'   PV   \tab Small   \tab   ALL   \cr
+#'   PV   \tab Mediumbus   \tab   ALL   \cr
+#'   PV   \tab Largebus   \tab   ALL   \cr
+#'   PV   \tab Taxi   \tab   ALL   \cr
+#'   PV   \tab Bus   \tab   ALL   \cr
+#'   Trucks   \tab Bus   \tab   G   \cr
+#'   Trucks   \tab Light   \tab   G   \cr
+#'   Trucks   \tab Medium   \tab   G   \cr
+#'   Trucks   \tab Heavy   \tab   G   \cr
+#'   Trucks   \tab Light   \tab   D   \cr
+#'   Trucks   \tab Medium   \tab   D   \cr
+#'   Trucks   \tab Heavy   \tab   D   \cr
+#'   Trucks   \tab Low Speed   \tab   D   \cr
+#'   Trucks   \tab Mini   \tab   D   \cr
+#' }
+
 #' @seealso \code{\link{ef_ldv_speed}} \code{\link{emis_hot_td}}
 #' @export
 #' @examples {
 #' # when standard is 'character'
-#' ef_china(standard = c("I"), p = "CO", details = TRUE)
+#' # Checking
+#' df_st <- rev(c(as.character(as.roman(5:1)), "PRE"))
+#' ef_china(t = "Mini", f = "G", standard = df_st, p = "CO")
+#' ef_china(t = "Mini", f = "G", standard = df_st, p = "HC")
+#' ef_china(t = "Mini", f = "G", standard = df_st, p = "NOx")
+#' ef_china(t = "Mini", f = "G", standard = df_st, p = "PM2.5")
+#' ef_china(t = "Mini", f = "G", standard = df_st, p = "PM10")
+#'
+#' ef_china(t = "Small", f = "G", standard = df_st, p = "CO")
+#' ef_china(t = "Small", f = "G", standard = df_st, p = "HC")
+#' ef_china(t = "Small", f = "G", standard = df_st, p = "NOx")
+#' ef_china(t = "Small", f = "G", standard = df_st, p = "PM2.5")
+#' ef_china(t = "Small", f = "G", standard = df_st, p = "PM10")
+#'
+#'
+#' ef_china(t = "Mini",
+#'         standard = c("PRE"),
+#'         p = "CO",
+#'         k = 1,
+#'         ta = celsius(15),
+#'         humidity = 0.5,
+#'         altitude = 1000,
+#'         speed = Speed(30),
+#'         baseyear_det = 2014,
+#'         sulphur = 50,
+#'         load_factor = 0.5,
+#'         details = FALSE)
 #' ef_china(standard = c("PRE", "I"), p = "CO", correction_only = TRUE)
+#'
 #' # when standard is 'data.frame'
 #' df_st <- matrix(c("V", "IV", "III", "III", "II", "I", "PRE"), nrow = 2, ncol = 7, byrow = TRUE)
 #' df_st <- as.data.frame(df_st)
-#' a <- ef_china(standard = df_st, p = "PM10", ta = rep(celsius(20), 2),
-#' altitude = rep(1501, 2), speed = rep(Speed(29), 2), sulphur = rep(50, 2))
+#' a <- ef_china(standard = df_st,
+#'               p = "PM10",
+#'               ta = rep(celsius(15), 2),
+#'               altitude = rep(1000, 2),
+#'               speed = rep(Speed(30), 2),
+#'               sulphur = rep(50, 2))
 #' dim(a)
 #' dim(df_st)
 #' ef_china(standard = df_st, p = "PM2.5", ta = rep(celsius(20), 2),
 #' altitude = rep(1501, 2), speed = rep(Speed(29), 2), sulphur = rep(50, 2))
 #' a
+#'
 #' # when standard, temperature and humidity are data.frames
 #' # assuming 10 regions
 #' df_st <- matrix(c("V", "IV", "III", "III", "II", "I", "PRE"), nrow = 10, ncol = 7, byrow = TRUE)
@@ -57,6 +123,7 @@
 #' df_t <- matrix(21:30, nrow = 10, ncol = 12, byrow = TRUE)
 #' df_t <- as.data.frame(df_t)
 #' for(i in 1:12) df_t[, i] <- celsius(df_t[, i])
+#'
 #' # assuming 10 regions
 #' df_h <- matrix(seq(0.4, 0.5, 0.05), nrow = 10, ncol = 12, byrow = TRUE)
 #' df_h <- as.data.frame(df_h)
@@ -77,10 +144,10 @@ ef_china <- function(v = "PV",
                      standard,
                      p,
                      k = 1,
-                     ta = celsius(25),
+                     ta = celsius(15),
                      humidity = 0.5,
                      altitude = 1000,
-                     speed = Speed(29),
+                     speed = Speed(30),
                      baseyear_det = 2016,
                      sulphur = 50,
                      load_factor = 0.5,
@@ -90,10 +157,10 @@ ef_china <- function(v = "PV",
   det_china <- sysdata$det_china
   sulphur_china <- sysdata$sulphur_china
   speed_china <- sysdata$speed_china
-  ef_china <- ef_china[!ef_china$POLLUTANT %in% c("Evaporative_driving",
-                                                  "Evaporative_parking"), ]
   ev <- ef_china[ef_china$POLLUTANT %in% c("Evaporative_driving",
                                            "Evaporative_parking"), ]
+  ef_china <- ef_china[!ef_china$POLLUTANT %in% c("Evaporative_driving",
+                                                  "Evaporative_parking"), ]
   fl <- data.frame(stringsAsFactors=FALSE,
                    POLLUTANT = c("CO", "HC", "NOx", "PM2.5", "PM10"),
                    L0 = c(0.87, 1, 0.83, 0.9, 0.9),
@@ -150,6 +217,7 @@ ef_china <- function(v = "PV",
                        ef_china$FUEL == f &
                        ef_china$STANDARD == standard[i] &
                        ef_china$POLLUTANT == p, ]
+
       # details
       if(details){
         cat("English: ", df$Description)
@@ -164,7 +232,7 @@ ef_china <- function(v = "PV",
       if(class(ta) != "units") stop("ta must be units in celsius, use celsius(ta)")
       ta <- as.numeric(ta)
 
-            # Check correction gasoline - ta
+      # Check correction gasoline - ta
       if(f == "G"){
         if(t != "Motorcycles"){
           if(p == "CO"){
@@ -218,25 +286,35 @@ ef_china <- function(v = "PV",
       }
       # Check correction NOx - humidity
       if(p == "NOx" & f == "G"){
-        df$EF <- ifelse(humidity > 0.5, df$EF*0.92, df$EF*1.06)
+        df$EF <- ifelse(humidity <0.5, df$EF*1.06,
+                        ifelse(
+                          humidity > 0.5, df$EF*0.92,
+                          df$EF))
       } else if(p == "NOx" & f == "D"){
-        df$EF <- ifelse(humidity > 0.5, df$EF*0.94, df$EF*1.04)
-      } else {
-        df$EF <- df$EF
+        df$EF <- ifelse(humidity < 0.5, df$EF*1.04,
+                        ifelse(
+                          humidity > 0.5, df$EF*0.94,
+                          df$EF))
       }
       # Check correction ta and humidity - gasoline
       if(ta > 24){
         if(f == "G"){
           if(p == "CO"){
-            df$EF <- ifelse(humidity > 0.5, df$EF*1.04, df$EF*0.97)
+            df$EF <- ifelse(
+              humidity > 0.5, df$EF*1.04,
+              ifelse(humidity < 0.5, df$EF*0.97, df$EF))
           } else if (p == "HC"){
-            df$EF <- ifelse(humidity > 0.5, df$EF*1.01, df$EF*0.99)
+            df$EF <- ifelse(
+              humidity > 0.5, df$EF*1.01,
+              ifelse(humidity < 0.5, df$EF*0.99, df$EF))
           } else if(p == "NOx"){
-            df$EF <- ifelse(humidity > 0.5, df$EF*0.87, df$EF*1.13)
+            df$EF <- ifelse(humidity > 0.5, df$EF*0.87,
+                            ifelse(humidity < 0.5, df$EF*1.13, df$EF))
           }
         } else if(f == "D"){
           if(p == "NOx"){
-            df$EF <- ifelse(humidity > 0.5, df$EF*0.88, df$EF*1.12)
+            df$EF <- ifelse(humidity > 0.5, df$EF*0.88,
+                            ifelse(humidity < 0.5, df$EF*1.12, df$EF))
           }
         }
       }
@@ -274,9 +352,12 @@ ef_china <- function(v = "PV",
         ifelse(
           speed >= 20 & speed < 30, df$EF*efspeed$S20_30,
           ifelse(
-            speed >= 30 & speed < 40, df$EF*efspeed$S30_40,
+            speed == 30 , df$EF,
             ifelse(
-              speed >= 40 & speed < 80, df$EF*efspeed$S40_80, df$EF*efspeed$S80))))
+              speed > 30 & speed < 40, df$EF*efspeed$S30_40,
+              ifelse(
+                speed >= 40 & speed < 80, df$EF*efspeed$S40_80,
+                ifelse(speed > 80, df$EF*efspeed$S80, 0))))))
       # Check deterioration
       if(f == "G" & p %in% c("CO", "HC", "NOx")){
         ts <- ifelse(t %in% c("Mini", "Small"),"group1",
@@ -297,19 +378,24 @@ ef_china <- function(v = "PV",
           sulphur > 10 & sulphur <= 50, df$EF*sulphur_china$S50,
           ifelse(
             sulphur > 50 & sulphur <= 150, df$EF*sulphur_china$S150,
-            df$EF*sulphur_china$S500)))
+            ifelse(sulphur > 150 & sulphur <= 350, df$EF*sulphur_china$S350,
+                   ifelse(
+                     sulphur > 350 & sulphur <= 500, df$EF*sulphur_china$S500,
+                     df$EF*sulphur_china$S800)))))
       # Check load
       dfl <- fl[fl$POLLUTANT == p, ]
       df$EF <- ifelse(
         load_factor == 0, df$EF*dfl$L0,
         ifelse(
-          load_factor > 0 & load_factor <= 0.5, df$EF*dfl$L50,
-          ifelse(
-            load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
-            ifelse(
-              load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
-              df$EF*dfl$L100))))
+          load_factor > 0 & load_factor < 0.5, df$EF*dfl$L50,
+          ifelse(load_factor == 0.5, df$EF,
+                 ifelse(
+                   load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
+                   ifelse(
+                     load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
+                     df$EF*dfl$L100)))))
     })
+
     if(correction_only){
       return(unlist(dff)*k)
     } else {
@@ -335,7 +421,7 @@ ef_china <- function(v = "PV",
 
         if(length(ta) != nrow(standard)) stop("length of 'ta' must be the same as the number of rows of 'standard'")
 
-                # Check correction gasoline - ta
+        # Check correction gasoline - ta
         if(f == "G"){
           if(t != "Motorcycles"){
             if(p == "CO"){
@@ -351,6 +437,7 @@ ef_china <- function(v = "PV",
               df$EF <- df$EF
             }
           }}
+
         # Check correction diesel - ta
         if(f == "D"){
           if(p == "CO"){
@@ -413,6 +500,7 @@ ef_china <- function(v = "PV",
             }
           }
         }
+
         # Check altitude
         if(length(altitude) != nrow(standard)) stop("length of 'altitude' must be the same as the number of rows of 'standard'")
         if(altitude[j] > 1500){
@@ -441,6 +529,7 @@ ef_china <- function(v = "PV",
         } else {
           df$EF <- df$EF
         }
+
         # Check speed
         if(length(speed) != nrow(standard)) stop("length of 'speed' must be the same as the number of rows of 'standard'")
         efspeed <- speed_china[speed_china$FUEL == f &
@@ -451,9 +540,11 @@ ef_china <- function(v = "PV",
           ifelse(
             speed[j] >= 20 & speed[j] < 30, df$EF*efspeed$S20_30,
             ifelse(
-              speed[j] >= 30 & speed[j] < 40, df$EF*efspeed$S30_40,
+              speed[j] == 30 , df$EF,
               ifelse(
-                speed[j] >= 40 & speed[j] < 80, df$EF*efspeed$S40_80, df$EF*efspeed$S80))))
+                speed[j] > 30 & speed[j] < 40, df$EF*efspeed$S30_40,
+                ifelse(
+                  speed[j] >= 40 & speed[j] < 80, df$EF*efspeed$S40_80, df$EF*efspeed$S80)))))
 
         # Check deterioration
         if(f == "G" & p %in% c("CO", "HC", "NOx")){
@@ -477,18 +568,23 @@ ef_china <- function(v = "PV",
             sulphur[j] > 10 & sulphur[j] <= 50, df$EF*sulphur_china$S50,
             ifelse(
               sulphur[j] > 50 & sulphur[j] <= 150, df$EF*sulphur_china$S150,
-              df$EF*sulphur_china$S500)))
+              ifelse(sulphur[j] > 150 & sulphur[j] <= 350, df$EF*sulphur_china$S350,
+                     ifelse(
+                       sulphur[j] > 350 & sulphur[j] <= 500, df$EF*sulphur_china$S500,
+                       df$EF*sulphur_china$S800)))))
+
         # Check load
         dfl <- fl[fl$POLLUTANT == p, ]
         df$EF <- ifelse(
           load_factor == 0, df$EF*dfl$L0,
           ifelse(
-            load_factor > 0 & load_factor <= 0.5, df$EF*dfl$L50,
-            ifelse(
-              load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
-              ifelse(
-                load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
-                df$EF*dfl$L100))))
+            load_factor > 0 & load_factor < 0.5, df$EF*dfl$L50,
+            ifelse(load_factor == 0.5, df$EF,
+                   ifelse(
+                     load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
+                     ifelse(
+                       load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
+                       df$EF*dfl$L100)))))
 
         df$EF
       }))
@@ -644,9 +740,11 @@ ef_china <- function(v = "PV",
             ifelse(
               speed[j] >= 20 & speed[j] < 30, df$EF*efspeed$S20_30,
               ifelse(
-                speed[j] >= 30 & speed[j] < 40, df$EF*efspeed$S30_40,
+                speed[j] == 30 , df$EF,
                 ifelse(
-                  speed[j] >= 40 & speed[j] < 80, df$EF*efspeed$S40_80, df$EF*efspeed$S80))))
+                  speed[j] > 30 & speed[j] < 40, df$EF*efspeed$S30_40,
+                  ifelse(
+                    speed[j] >= 40 & speed[j] < 80, df$EF*efspeed$S40_80, df$EF*efspeed$S80)))))
 
           # Check deterioration
           if(f == "G" & p %in% c("CO", "HC", "NOx")){
@@ -670,18 +768,22 @@ ef_china <- function(v = "PV",
               sulphur[j] > 10 & sulphur[j] <= 50, df$EF*sulphur_china$S50,
               ifelse(
                 sulphur[j] > 50 & sulphur[j] <= 150, df$EF*sulphur_china$S150,
-                df$EF*sulphur_china$S500)))
+                ifelse(sulphur[j] > 150 & sulphur[j] <= 350, df$EF*sulphur_china$S350,
+                       ifelse(
+                         sulphur[j] > 350 & sulphur[j] <= 500, df$EF*sulphur_china$S500,
+                         df$EF*sulphur_china$S800)))))
           # Check load
           dfl <- fl[fl$POLLUTANT == p, ]
           df$EF <- ifelse(
             load_factor == 0, df$EF*dfl$L0,
             ifelse(
-              load_factor > 0 & load_factor <= 0.5, df$EF*dfl$L50,
-              ifelse(
-                load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
-                ifelse(
-                  load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
-                  df$EF*dfl$L100))))
+              load_factor > 0 & load_factor < 0.5, df$EF*dfl$L50,
+              ifelse(load_factor == 0.5, df$EF,
+                     ifelse(
+                       load_factor > 0.5 & sulphur <= 0.6, df$EF*dfl$L60,
+                       ifelse(
+                         load_factor > 0.6 & sulphur <= 0.75, df$EF*dfl$L75,
+                         df$EF*dfl$L100)))))
           df$EF
         }))
       }))
