@@ -33,7 +33,7 @@
 #' \strong{Pollutants (g/km)}: "CO", "NOx", "HC", "PM", "CH4", "NMHC", "CO2", "SO2",
 #' "Pb".
 #'
-#' \strong{Black CArbon and Organic Matter (g/km)}: "BC", "OM"
+#' \strong{Black Carbon and Organic Matter (g/km)}: "BC", "OM"
 #'
 #' \strong{PAH and POP (g/km)}: "indeno(1,2,3-cd)pyrene", "benzo(k)fluoranthene",
 #' "benzo(ghi)perylene", "fluoranthene",
@@ -63,7 +63,8 @@
 #'
 #' \emph{KETONES (g/km)}: "acetone"
 #'
-#' \emph{AROMATICS (g/km)}: "toluene", "ethylbenzene", "m,p-xylene", "o-xylene",
+#' \emph{AROMATICS (g/km)}: "toluene", "ethylbenzene",
+#'  "m-xylene",  "p-xylene", "o-xylene",
 #' "1,2,3-trimethylbenzene", "1,2,4-trimethylbenzene",
 #' "1,3,5-trimethylbenzene", "styrene", "benzene", "C9".
 #'
@@ -243,7 +244,7 @@ ef_hdv_speed <- function(v, t, g, eu, x, gr = 0, l = 0.5 ,p, k=1,
         return(f1)
       }
 
-    } else if(length(eu) > 1){
+    } else if(length(eu) > 1) {
       if(missing(speed)) stop("if length(eu) > 1, 'speed' is needed")
       dff <- do.call("cbind", lapply(1:length(eu), function(i){
         df <- ef_hdv[ef_hdv$VEH == v &
@@ -282,7 +283,7 @@ ef_hdv_speed <- function(v, t, g, eu, x, gr = 0, l = 0.5 ,p, k=1,
     }
 
   } else if (is.data.frame(eu)){
-    if(missing(speed)) stop("Add 'speed' please")
+    if(missing(speed)) stop("Add 'speed' please for each row")
     dff <- do.call("rbind", lapply(1:nrow(eu), function(j){
       do.call("cbind", lapply(1:ncol(eu), function(i){
 
