@@ -16,7 +16,7 @@
 #' @note The length of the list should be equal to the name of the age categories of
 #' a specific type of vehicle
 #' @export
-#' @examples \dontrun{
+#' @examples {
 #' # Do not run
 #' df <- data.frame(age1 = c(1,1), age2 = c(2,2))
 #' eu = c("I", "PRE")
@@ -32,5 +32,5 @@ ef_ldv_cold_list <- function(df,v = "LDV", ta, cc, f, eu, p) {
                          eu = as.character(eu[i]), p = p, k = 1,
                          show.equation = FALSE)
    })
-  return(EmissionFactorsList(lista))
+  return(lista)
 }
