@@ -8,7 +8,6 @@
 #' of the local emission factor, e.g. If the local emission factors were tested with the
 #' FTP-75 test procedure, SDC = 34.12 km/h.
 #'
-#' @param df Deprecated
 #' @param dfcol Column of the dataframe with the local emission factors eg df$dfcol
 #' @param SDC Speed of the driving cycle
 #' @param v Category vehicle: "PC", "LCV", "Motorcycle" or "Moped
@@ -22,6 +21,7 @@
 #' @param eu Euro standard: "PRE", "I", "II", "III", "III+DPF", "IV", "V", "VI", "VIc"
 #' @param p Pollutant: "CO", "FC", "NOx", "HC" or "PM". If your pollutant dfcol
 #' is based on fuel, use "FC", if it is based on "HC", use "HC".
+#' @param df deprecated
 #' @return A list of scaled emission factors  g/km
 #' @keywords speed emission factors
 #' @note The length of the list should be equal to the name of the age categories of
@@ -44,16 +44,15 @@
 #' main = "Variation of emissions with speed of newest vehicle")
 #' }
 ef_ldv_scaled <- function(df, dfcol ,SDC  = 34.12, v, t = "4S", cc, f, eu, p) {
-  if(!missing(df)){
-    message("argument 'df' will be deprecated")
-  }
-
-  lapply(1:length(dfcol), function(i)  {
+  if(length(dfcol) != length(eu)) stop("Length of dfcol must be the same as length of eu")
+  dfcol <- as.numeric(dfcol)
+  la <- lapply(1:length(dfcol), function(i)  {
     funIN <- ef_ldv_speed(v = v, t = t, cc = cc, f = f,
                          eu = as.character(eu[i]), p = p, k = 1, show.equation = FALSE)
     k <- dfcol[i]/ funIN(SDC)
-    funOUT <- ef_ldv_speed(v = v, t = t, cc = cc, f = f,
+    ef_ldv_speed(v = v, t = t, cc = cc, f = f,
                          eu = as.character(eu[i]), p = p, k = k,show.equation = FALSE)
-    return(funOUT)
    })
+  class(la) <- c("EmissionFactorsList",class(la))
+  return(la)
 }
