@@ -15,7 +15,7 @@
 #' http://spatialreference.org/ to transform/project spatial data using sf::st_transform.
 #' The default value is 4326
 #' @return A grid of polygons class 'sf'
-#' @importFrom sf st_as_sf st_sf st_crs st_bbox st_sfc
+#' @importFrom sf st_as_sf st_sf st_crs st_bbox st_sfc st_as_sfc
 #' @importFrom eixport wrf_grid
 #' @export
 #' @examples {
@@ -34,7 +34,13 @@ make_grid <- function(spobj, width, height = width,  polygon, crs = 4326, ...){
   }
 
 if(class(spobj)[1] != "character"){
-net <- sf::st_as_sf(spobj)
+  if(class(spobj) == "bbox") {
+    spobj <- sf::st_as_sfc(spobj)
+    spobj <- sf::st_sf(geometry = spobj)
+
+  }
+
+  net <- sf::st_as_sf(spobj)
     # g <- sf::st_make_grid(x = net, cellsize = width, ...)
 makinggrid <- function (x,
                         cellsize = c(width, height),
