@@ -10,7 +10,7 @@ PC_G <- c(33491,22340,24818,31808,46458,28574,24856,28972,37818,49050,87923,
           1181, 4991, 3711, 5653, 7039, 5839, 4257,3824, 3068)
 veh <- data.frame(PC_G = PC_G)
 pc1 <- my_age(x = net$ldv, y = PC_G, name = "PC")
-lef <- EmissionFactorsList(as.numeric(ef_cetesb("CO", "PC_G")))
+lef <- EmissionFactorsList(as.numeric(ef_cetesb("CO", "PC_G", year = 2016)))
 
 test_that("EmissionsArray works", {
   expect_equal(as.numeric(emis(veh = pc1[1:5, ],
